@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.1.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,8 +30,8 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_INI_BUILD_PHP_SRC_PHP_7_2_12_ZEND_ZEND_INI_PARSER_H_INCLUDED
-# define YY_INI_BUILD_PHP_SRC_PHP_7_2_12_ZEND_ZEND_INI_PARSER_H_INCLUDED
+#ifndef YY_INI_ZEND_ZEND_INI_PARSER_H_INCLUDED
+# define YY_INI_ZEND_ZEND_INI_PARSER_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -90,4 +90,4 @@ typedef int YYSTYPE;
 
 int ini_parse (void);
 
-#endif /* !YY_INI_BUILD_PHP_SRC_PHP_7_2_12_ZEND_ZEND_INI_PARSER_H_INCLUDED  */
+#endif /* !YY_INI_ZEND_ZEND_INI_PARSER_H_INCLUDED  */
